==> ejc-jlincome-api-3.0.0-20241111.115258-355-sources.jar: com/ejianc/business/jlincome/performance/vo/ForecastReportVO.java <==
package com.ejianc.business.jlincome.performance.vo;

import com.ejianc.foundation.share.utils.ITreeNodeB;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 绩效管理-销售预报台账
 *
 * @author generator
 */
public class ForecastReportVO extends BaseVO implements ITreeNodeB {
    private static final long serialVersionUID = 1L;


    private Long orgId; // 项目部主键
    private String orgName; // 项目部名称/区域名称
    private String orgCode; // 项目组织编码
    private String year; // 年份
    private String forecastMonth; // 预报月份
    private Long detailProjectId; // 所属项目ID
    private String detailProjectCode; // 所属项目code
    private String detailProjectName; // 所属项目名称
    private Long customerId; // 客户单位id
    private String customerName; // 客户单位名称
    private Long detailPersonId; // 负责人id
    private String detailPersonName; // 负责人
    private BigDecimal saleDetailMny; // 预计销售
    private BigDecimal invoiceDetailMny; // 预计开票
    private BigDecimal incomeDetailMny; // 预计回款

    private Long parentId; // 父级id
    private List<ITreeNodeB> children;
    public Long getParentId() {
        return parentId;
    }
    //这是设置 主表
    @Override
    public Long getNodeID() {
        //主显示   主表的id
        return getId();
    }

    @Override
    public Long getParentID() {
        return getParentId();
    }

    @Override
    public List<ITreeNodeB> getChildren() {
        if (children == null) {
            children = new ArrayList<>();
        }
        return children;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getYear() {
        return year;
    }

    public void setYear(String year) {
        this.year = year;
    }

    public String getForecastMonth() {
        return forecastMonth;
    }

    public void setForecastMonth(String forecastMonth) {
        this.forecastMonth = forecastMonth;
    }

    public Long getDetailProjectId() {
        return detailProjectId;
    }

    public void setDetailProjectId(Long detailProjectId) {
        this.detailProjectId = detailProjectId;
    }

    public String getDetailProjectCode() {
        return detailProjectCode;
    }

    public void setDetailProjectCode(String detailProjectCode) {
        this.detailProjectCode = detailProjectCode;
    }

    public String getDetailProjectName() {
        return detailProjectName;
    }

    public void setDetailProjectName(String detailProjectName) {
        this.detailProjectName = detailProjectName;
    }

    public Long getCustomerId() {
        return customerId;
    }

    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }

    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }

    public Long getDetailPersonId() {
        return detailPersonId;
    }

    public void setDetailPersonId(Long detailPersonId) {
        this.detailPersonId = detailPersonId;
    }

    public String getDetailPersonName() {
        return detailPersonName;
    }

    public void setDetailPersonName(String detailPersonName) {
        this.detailPersonName = detailPersonName;
    }

    public BigDecimal getSaleDetailMny() {
        return saleDetailMny;
    }

    public void setSaleDetailMny(BigDecimal saleDetailMny) {
        this.saleDetailMny = saleDetailMny;
    }

    public BigDecimal getInvoiceDetailMny() {
        return invoiceDetailMny;
    }

    public void setInvoiceDetailMny(BigDecimal invoiceDetailMny) {
        this.invoiceDetailMny = invoiceDetailMny;
    }

    public BigDecimal getIncomeDetailMny() {
        return incomeDetailMny;
    }

    public void setIncomeDetailMny(BigDecimal incomeDetailMny) {
        this.incomeDetailMny = incomeDetailMny;
    }
}

==> ejc-jlincome-api-3.0.0-20241126.025128-384-sources.jar: com/ejianc/business/jlincome/performance/vo/ForecastReportVO.java <==
package com.ejianc.business.jlincome.performance.vo;

import com.ejianc.foundation.share.utils.ITreeNodeB;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 绩效管理-销售预报台账
 *
 * @author generator
 */
public class ForecastReportVO extends BaseVO implements ITreeNodeB {
    private static final long serialVersionUID = 1L;


    private Long orgId; // 项目部主键
    private String orgName; // 项目部名称/区域名称
    private String orgCode; // 项目组织编码
    private String year; // 年份
    private String forecastMonth; // 预报月份
    private Long detailProjectId; // 所属项目ID
    private String detailProjectCode; // 所属项目code
    private String detailProjectName; // 所属项目名称
    private Long customerId; // 客户单位id
    private String customerName; // 客户单位名称
    private Long detailPersonId; // 负责人id
    private String detailPersonName; // 负责人
    private BigDecimal saleDetailMny; // 预计销售
    private BigDecimal invoiceDetailMny; // 预计开票
    private BigDecimal incomeDetailMny; // 预计回款
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date successDate; // 完成时间

    private Long parentId; // 父级id
    private List<ITreeNodeB> children;
    public Long getParentId() {
        return parentId;
    }
    //这是设置 主表
    @Override
    public Long getNodeID() {
        //主显示   主表的id
        return getId();
    }

    @Override
    public Long getParentID() {
        return getParentId();
    }

    @Override
    public List<ITreeNodeB> getChildren() {
        if (children == null) {
            children = new ArrayList<>();
        }
        return children;
    }

    public Date getSuccessDate() {
        return successDate;
    }

    public void setSuccessDate(Date successDate) {
        this.successDate = successDate;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getYear() {
        return year;
    }

    public void setYear(String year) {
        this.year = year;
    }

    public String getForecastMonth() {
        return forecastMonth;
    }

    public void setForecastMonth(String forecastMonth) {
        this.forecastMonth = forecastMonth;
    }

    public Long getDetailProjectId() {
        return detailProjectId;
    }

    public void setDetailProjectId(Long detailProjectId) {
        this.detailProjectId = detailProjectId;
    }

    public String getDetailProjectCode() {
        return detailProjectCode;
    }

    public void setDetailProjectCode(String detailProjectCode) {
        this.detailProjectCode = detailProjectCode;
    }

    public String getDetailProjectName() {
        return detailProjectName;
    }

    public void setDetailProjectName(String detailProjectName) {
        this.detailProjectName = detailProjectName;
    }

    public Long getCustomerId() {
        return customerId;
    }

    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }

    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }

    public Long getDetailPersonId() {
        return detailPersonId;
    }

    public void setDetailPersonId(Long detailPersonId) {
        this.detailPersonId = detailPersonId;
    }

    public String getDetailPersonName() {
        return detailPersonName;
    }

    public void setDetailPersonName(String detailPersonName) {
        this.detailPersonName = detailPersonName;
    }

    public BigDecimal getSaleDetailMny() {
        return saleDetailMny;
    }

    public void setSaleDetailMny(BigDecimal saleDetailMny) {
        this.saleDetailMny = saleDetailMny;
    }

    public BigDecimal getInvoiceDetailMny() {
        return invoiceDetailMny;
    }

    public void setInvoiceDetailMny(BigDecimal invoiceDetailMny) {
        this.invoiceDetailMny = invoiceDetailMny;
    }

    public BigDecimal getIncomeDetailMny() {
        return incomeDetailMny;
    }

    public void setIncomeDetailMny(BigDecimal incomeDetailMny) {
        this.incomeDetailMny = incomeDetailMny;
    }
}
